@@ -4,6 +4,6 @@ from pluggy import HookimplMarker
 hookimpl = HookimplMarker("testit")
 
 __all__ = [
-    'plugin_manager',
+    'TestITPluginManager',
     'hookimpl'
 ]
