@@ -1,6 +1,7 @@
 import configparser
 import inspect
 import os
+import pickle
 from datetime import datetime
 
 import pytest
@@ -64,30 +65,44 @@ class TestITListener(object):
                     search_in_environ(parser.get('testit', 'projectID')))
                 self.configuration_id = uuid_check(
                     search_in_environ(parser.get('testit', 'configurationID')))
+
+                if parser.has_option('testit', 'testrun_name'):
+                    self.testrun_name = parser.get('testit', 'testrun_name')
         self.requests = Api(url, private_token, proxy=proxy)
 
+    @pytest.hookimpl
+    def pytest_configure(self, config):
+        if not hasattr(config, "workerinput") and not hasattr(self, "testrun_id"):
+            config.testrun_id = self.requests.create_testrun(
+                JSONFixture.create_testrun(
+                    self.project_id,
+                    f'{self.testrun_name if hasattr(self, "testrun_name") else "LocalRun"} {datetime.today().strftime("%d %b %Y %H:%M:%S")}'))
+            self.requests.testrun_activity(config.testrun_id, 'start')
+
+    @pytest.hookimpl
+    def pytest_configure_node(self, node):
+        if not hasattr(self, "testrun_id"):
+            node.workerinput["testrun_id"] = pickle.dumps(node.config.testrun_id)
+
     @pytest.hookimpl
     def pytest_collection_modifyitems(self, session, config, items):
         index = 0
         new_items = []
         plugin_info = config.pluginmanager.list_plugin_distinfo()
+
         for plugin, dist in plugin_info:
             if 'pytest_check' == dist.project_name:
                 from pytest_check import check_methods
                 self.pytest_check_get_failures = check_methods.get_failures
                 break
 
-        if hasattr(self, 'testrun_id'):
-            self.project_id, data_autotests = self.requests.get_testrun(
-                self.testrun_id)
-            configurations_array = configurations_parser(data_autotests)
-        else:
-            self.testrun_id = self.requests.create_testrun(
-                JSONFixture.create_testrun(
-                    self.project_id,
-                    f'LocalRun {datetime.today().strftime("%d %b %Y %H:%M:%S")}'))
-            self.requests.testrun_activity(self.testrun_id, 'start')
-            configurations_array = None
+        if not hasattr(self, "testrun_id"):
+            self.testrun_id = pickle.loads(config.workerinput["testrun_id"]) if\
+                hasattr(config, 'workerinput') else config.testrun_id
+
+        self.project_id, data_autotests = self.requests.get_testrun(
+        self.testrun_id)
+        configurations_array = configurations_parser(data_autotests)
 
         for item in items:
             if hasattr(item.function, 'test_external_id'):
@@ -143,7 +158,7 @@ class TestITListener(object):
     @pytest.hookimpl(hookwrapper=True)
     def pytest_fixture_setup(self, fixturedef):
         yield
-        if self.item:
+        if hasattr(self, 'item') and self.item:
             steps_data, results_steps_data = step.get_steps_data()
             if fixturedef.scope == 'function':
                 if not hasattr(self.item, 'test_method_setup_steps'):
@@ -155,7 +170,7 @@ class TestITListener(object):
     @pytest.hookimpl(hookwrapper=True, trylast=True)
     def pytest_runtest_call(self):
         yield
-        if not self.item:
+        if hasattr(self, 'item') and not self.item:
             return
         test_steps, test_results_steps = step.get_steps_data()
         self.item.test_steps = test_steps
@@ -163,7 +178,7 @@ class TestITListener(object):
 
     @pytest.hookimpl
     def pytest_fixture_post_finalizer(self, fixturedef):
-        if not self.item:
+        if hasattr(self, 'item') and not self.item:
             return
         teardown_steps, teardown_results_steps = step.get_steps_data()
         if fixturedef.scope == 'function':
@@ -175,7 +190,7 @@ class TestITListener(object):
 
     @pytest.hookimpl
     def pytest_runtest_logreport(self, report):
-        if self.item:
+        if hasattr(self, 'item') and self.item:
             if report.failed or hasattr(report, 'wasxfail') \
                     and not report.passed or report.outcome == 'rerun':
                 if not hasattr(self.item, 'test_traces'):
@@ -191,7 +206,7 @@ class TestITListener(object):
 
     @pytest.hookimpl
     def pytest_runtest_logfinish(self):
-        if not self.item:
+        if not hasattr(self, 'item') or not self.item:
             return
         data_item = self.attribute_collector(self.item)
         if data_item:
