@@ -123,9 +123,14 @@ class step:
             else:
                 name = f'Step {str(len(self.steps_data) + 1)}'
 
-            if args:
+            args_default_values = inspect.getfullargspec(function).defaults
+            if args or args_default_values:
+                if args_default_values:
+                    args += args_default_values
+
                 function_args_name = inspect.getfullargspec(function).args
                 step_args = [arg_name for arg_name in function_args_name if arg_name not in list(kwargs)]
+
                 for id in range(0, len(step_args)):
                     parameters[step_args[id]] = str(args[id])
             if kwargs:
@@ -140,9 +145,14 @@ class step:
             @wraps(function)
             def step_wrapper(*a, **kw):
                 if self.args:
-                    if a:
+                    args_default_values = inspect.getfullargspec(function).defaults
+                    if a or args_default_values:
+                        if args_default_values:
+                            a += args_default_values
+
                         function_args_name = inspect.getfullargspec(function).args
                         step_args = [arg_name for arg_name in function_args_name if arg_name not in list(kw)]
+
                         for id in range(0, len(step_args)):
                             parameters[step_args[id]] = str(a[id])
                     if kw:
